pub struct Config {
pub keys: SessionKeys,
pub profile: ProtectionProfile,
pub local_rtp_options: Option<ContextOption>,
pub remote_rtp_options: Option<ContextOption>,
pub local_rtcp_options: Option<ContextOption>,
pub remote_rtcp_options: Option<ContextOption>,
}Expand description
Config is used to configure a session. You can provide either a KeyingMaterialExporter to export keys or directly pass the keys themselves. After a Config is passed to a session it must not be modified.
Fields
keys: SessionKeysThe master keys and salts for both directions.
profile: ProtectionProfileThe negotiated protection profile, which fixes the cipher and tag lengths.
local_rtp_options: Option<ContextOption>List of local/remote context options. ReplayProtection is enabled on remote context by default. Default replay protection window size is 64.
remote_rtp_options: Option<ContextOption>Replay-protection options for the inbound RTP context. Enabled by default.
local_rtcp_options: Option<ContextOption>Replay-protection options for the outbound RTCP context.
remote_rtcp_options: Option<ContextOption>Replay-protection options for the inbound RTCP context. Enabled by default.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn extract_session_keys_from_dtls(
&mut self,
exporter: &impl KeyingMaterialExporter,
is_client: bool,
) -> Result<()>
pub fn extract_session_keys_from_dtls( &mut self, exporter: &impl KeyingMaterialExporter, is_client: bool, ) -> Result<()>
ExtractSessionKeysFromDTLS allows setting the Config SessionKeys by extracting them from DTLS. This behavior is defined in RFC5764: https://tools.ietf.org/html/rfc5764